# Engineering Feature

A specific type of engineering feature object is designed for each type of engineering feature.

## Create engineering features

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.EngineeringFeature.EngineeringFeature
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.EngineeringFeature
        :recursive:
        :exclude: EngineeringFeature
```
